@@ -69,7 +69,7 @@ class Exceptions:
 
 class CloudHSMClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html)
     """
 
@@ -80,19 +80,25 @@ class CloudHSMClient:
         self, *, ResourceArn: str, TagList: List["TagTypeDef"]
     ) -> AddTagsToResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Client.add_tags_to_resource)
+        This is documentation for **AWS CloudHSM Classic**.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.add_tags_to_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#add_tags_to_resource)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#can_paginate)
         """
 
     def create_hapg(self, *, Label: str) -> CreateHapgResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Client.create_hapg)
+        This is documentation for **AWS CloudHSM Classic**.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.create_hapg)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#create_hapg)
         """
 
@@ -109,7 +115,9 @@ class CloudHSMClient:
         SyslogIp: str = None
     ) -> CreateHsmResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Client.create_hsm)
+        This is documentation for **AWS CloudHSM Classic**.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.create_hsm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#create_hsm)
         """
 
@@ -117,31 +125,41 @@ class CloudHSMClient:
         self, *, Certificate: str, Label: str = None
     ) -> CreateLunaClientResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Client.create_luna_client)
+        This is documentation for **AWS CloudHSM Classic**.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.create_luna_client)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#create_luna_client)
         """
 
     def delete_hapg(self, *, HapgArn: str) -> DeleteHapgResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Client.delete_hapg)
+        This is documentation for **AWS CloudHSM Classic**.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.delete_hapg)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#delete_hapg)
         """
 
     def delete_hsm(self, *, HsmArn: str) -> DeleteHsmResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Client.delete_hsm)
+        This is documentation for **AWS CloudHSM Classic**.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.delete_hsm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#delete_hsm)
         """
 
     def delete_luna_client(self, *, ClientArn: str) -> DeleteLunaClientResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Client.delete_luna_client)
+        This is documentation for **AWS CloudHSM Classic**.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.delete_luna_client)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#delete_luna_client)
         """
 
     def describe_hapg(self, *, HapgArn: str) -> DescribeHapgResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Client.describe_hapg)
+        This is documentation for **AWS CloudHSM Classic**.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.describe_hapg)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#describe_hapg)
         """
 
@@ -149,7 +167,9 @@ class CloudHSMClient:
         self, *, HsmArn: str = None, HsmSerialNumber: str = None
     ) -> DescribeHsmResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Client.describe_hsm)
+        This is documentation for **AWS CloudHSM Classic**.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.describe_hsm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#describe_hsm)
         """
 
@@ -157,7 +177,9 @@ class CloudHSMClient:
         self, *, ClientArn: str = None, CertificateFingerprint: str = None
     ) -> DescribeLunaClientResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Client.describe_luna_client)
+        This is documentation for **AWS CloudHSM Classic**.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.describe_luna_client)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#describe_luna_client)
         """
 
@@ -169,7 +191,9 @@ class CloudHSMClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#generate_presigned_url)
         """
 
@@ -177,37 +201,49 @@ class CloudHSMClient:
         self, *, ClientArn: str, ClientVersion: ClientVersionType, HapgList: List[str]
     ) -> GetConfigResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Client.get_config)
+        This is documentation for **AWS CloudHSM Classic**.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.get_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#get_config)
         """
 
     def list_available_zones(self) -> ListAvailableZonesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Client.list_available_zones)
+        This is documentation for **AWS CloudHSM Classic**.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.list_available_zones)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#list_available_zones)
         """
 
     def list_hapgs(self, *, NextToken: str = None) -> ListHapgsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Client.list_hapgs)
+        This is documentation for **AWS CloudHSM Classic**.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.list_hapgs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#list_hapgs)
         """
 
     def list_hsms(self, *, NextToken: str = None) -> ListHsmsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Client.list_hsms)
+        This is documentation for **AWS CloudHSM Classic**.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.list_hsms)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#list_hsms)
         """
 
     def list_luna_clients(self, *, NextToken: str = None) -> ListLunaClientsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Client.list_luna_clients)
+        This is documentation for **AWS CloudHSM Classic**.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.list_luna_clients)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#list_luna_clients)
         """
 
     def list_tags_for_resource(self, *, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Client.list_tags_for_resource)
+        This is documentation for **AWS CloudHSM Classic**.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#list_tags_for_resource)
         """
 
@@ -215,7 +251,9 @@ class CloudHSMClient:
         self, *, HapgArn: str, Label: str = None, PartitionSerialList: List[str] = None
     ) -> ModifyHapgResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Client.modify_hapg)
+        This is documentation for **AWS CloudHSM Classic**.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.modify_hapg)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#modify_hapg)
         """
 
@@ -230,7 +268,9 @@ class CloudHSMClient:
         SyslogIp: str = None
     ) -> ModifyHsmResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Client.modify_hsm)
+        This is documentation for **AWS CloudHSM Classic**.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.modify_hsm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#modify_hsm)
         """
 
@@ -238,7 +278,9 @@ class CloudHSMClient:
         self, *, ClientArn: str, Certificate: str
     ) -> ModifyLunaClientResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Client.modify_luna_client)
+        This is documentation for **AWS CloudHSM Classic**.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.modify_luna_client)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#modify_luna_client)
         """
 
@@ -246,20 +288,24 @@ class CloudHSMClient:
         self, *, ResourceArn: str, TagKeyList: List[str]
     ) -> RemoveTagsFromResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Client.remove_tags_from_resource)
+        This is documentation for **AWS CloudHSM Classic**.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.remove_tags_from_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#remove_tags_from_resource)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_hapgs"]) -> ListHapgsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHapgs)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/paginators.html#listhapgspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHapgs)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/paginators.html#listhapgspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_hsms"]) -> ListHsmsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHsms)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/paginators.html#listhsmspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHsms)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/paginators.html#listhsmspaginator)
         """
 
     @overload
@@ -267,5 +313,6 @@ class CloudHSMClient:
         self, operation_name: Literal["list_luna_clients"]
     ) -> ListLunaClientsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/cloudhsm.html#CloudHSM.Paginator.ListLunaClients)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/paginators.html#listlunaclientspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Paginator.ListLunaClients)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/paginators.html#listlunaclientspaginator)
         """
