@@ -6,9 +6,9 @@ Type annotations for cloudhsm service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_cloudhsm.literals import ClientVersion
+    from mypy_boto3_cloudhsm.literals import ClientVersionType
 
-    data: ClientVersion = "5.1"
+    data: ClientVersionType = "5.1"
     ```
 """
 import sys
@@ -20,22 +20,22 @@ else:
 
 
 __all__ = (
-    "ClientVersion",
-    "CloudHsmObjectState",
-    "HsmStatus",
+    "ClientVersionType",
+    "CloudHsmObjectStateType",
+    "HsmStatusType",
     "ListHapgsPaginatorName",
     "ListHsmsPaginatorName",
     "ListLunaClientsPaginatorName",
-    "SubscriptionType",
+    "SubscriptionTypeType",
 )
 
 
-ClientVersion = Literal["5.1", "5.3"]
-CloudHsmObjectState = Literal["DEGRADED", "READY", "UPDATING"]
-HsmStatus = Literal[
+ClientVersionType = Literal["5.1", "5.3"]
+CloudHsmObjectStateType = Literal["DEGRADED", "READY", "UPDATING"]
+HsmStatusType = Literal[
     "DEGRADED", "PENDING", "RUNNING", "SUSPENDED", "TERMINATED", "TERMINATING", "UPDATING"
 ]
 ListHapgsPaginatorName = Literal["list_hapgs"]
 ListHsmsPaginatorName = Literal["list_hsms"]
 ListLunaClientsPaginatorName = Literal["list_luna_clients"]
-SubscriptionType = Literal["PRODUCTION"]
+SubscriptionTypeType = Literal["PRODUCTION"]
